==> dart_chainsql_api-1.0.5.tar.gz: lib/src/core/coretypes/STArray.dart <==
import 'dart:core';
import 'dart:core' as prefix0;
import "dart:typed_data";
import 'package:dart_chainsql_api/src/core/fields/Field.dart';

import "../serialized/SerializedType.dart";
import "../fields/Type.dart";
import "../serialized/BytesSink.dart";
import "../serialized/TypeTranslator.dart";
import 'package:dart_chainsql_api/src/core/serialized/BinaryParser.dart';

import 'package:dart_chainsql_api/src/core/coretypes/STObject.dart';

class STArray  implements SerializedType {
  STArray() {

  }

  List<STObject> listSTObject = new List<STObject>();

  static STArrayTranslator translate = new STArrayTranslator();

  Map toJSON() => null;

  Uint8List toBytes() => translate.toBytes(this);

  String toHex() =>  translate.toHex(this);

  void toBytesSink(BytesSink to){

    for (STObject stObject in listSTObject){
      stObject.toBytesSink(to);
    }
  }


  STArray fromJSONArray( List<Map<String, dynamic>> jsonArray) {
    STArray arr = new STArray();

    for (int i = 0; i < jsonArray.length; i++) {
      Object o = jsonArray[i];
      arr.add(o);
    }

    return arr;
  }


  Type type() => Type.STArray;

  void add(STObject obj)  => listSTObject.add(obj);
}

class STArrayTranslator extends TypeTranslator<STArray> {
  STArray fromParser(BinaryParser parser, int hint) {

    STArray stArray = new STArray();
    while (!parser.isEnd()) {
      Field field = parser.readField();
      if (field == Field.ArrayEndMarker) {
        break;
      }
      STObject outer = new STObject();
      // assert field.getType() == Type.STObject;
      outer.put(field, STObject.translate.fromBinaryParser(parser));
      stArray.add(STObject.formatted(outer));
    }
    return stArray;


  }


  STArray fromJSONArray( List<Map<String, dynamic>> jsonArray) {

        STArray arr = new STArray();

        for (int i = 0; i < jsonArray.length; i++) {
       //   Object o = jsonArray[i];
          arr.add(STObject.fromJSONObject(  jsonArray[i]));
        }

        return arr;
  }


  //STArray fromJSONObject(Map<String, dynamic> jsonObject) =>null;


//
//  STObject fromJSONObject(Map jsonObject) {
//    STObject so = new STObject();
//
//    jsonObject.forEach((k,v){
//
//      Field fieldKey = Field.fromString(k);
//      Object value   = v;
//      if (fieldKey != null) {
//        so.putTranslated(fieldKey, value);
//      }
//    });
//
//    return STObject.formatted(so);
//  }


//  Blob fromString(String value) {
//    return new Blob(Util.createUint8ListFromString(value));
//  }
//
//  void toBytesSink(Blob obj, BytesSink to) {
//    to.addBytes(obj.buffer);
//  }

//TODO
//  String toString(Blob obj) {
//    return B16.toString(obj.buffer);
//  }

//  Blob fromParser(BinaryParser parser, int hint) {
//    if (hint == null) {
//      hint = parser.size() - parser.pos();
//    }
//    return new Blob(parser.read(hint));
//  }

}

==> dart_chainsql_api-1.0.8.tar.gz: lib/src/core/coretypes/STArray.dart <==
import 'dart:core';
import 'dart:core' as prefix0;
import "dart:typed_data";
import 'package:dart_chainsql_api/src/core/fields/Field.dart';

import "../serialized/SerializedType.dart";
import "../fields/Type.dart";
import "../serialized/BytesSink.dart";
import "../serialized/TypeTranslator.dart";
import 'package:dart_chainsql_api/src/core/serialized/BinaryParser.dart';

import 'package:dart_chainsql_api/src/core/coretypes/STObject.dart';

class STArray  implements SerializedType {
  STArray() {

  }

  List<STObject> listSTObject = new List<STObject>();

  static STArrayTranslator translate = new STArrayTranslator();

  Map toJSON() => null;

  Uint8List toBytes() => translate.toBytes(this);

  String toHex() =>  translate.toHex(this);

  void toBytesSink(BytesSink to){

    for (STObject stObject in listSTObject){
      stObject.toBytesSink(to);
    }
  }


//  STArray fromJSONArray( List<Map<String, dynamic>> jsonArray) {
//    STArray arr = new STArray();
//
//    for (int i = 0; i < jsonArray.length; i++) {
//      Object o = jsonArray[i];
//      arr.add(o);
//    }
//
//    return arr;
//  }


  Type type() => Type.STArray;

  void add(STObject obj)  => listSTObject.add(obj);
}

class STArrayTranslator extends TypeTranslator<STArray> {
  STArray fromParser(BinaryParser parser, int hint) {

    STArray stArray = new STArray();
    while (!parser.isEnd()) {
      Field field = parser.readField();
      if (field == Field.ArrayEndMarker) {
        break;
      }
      STObject outer = new STObject();
      // assert field.getType() == Type.STObject;
      outer.put(field, STObject.translate.fromBinaryParser(parser));
      stArray.add(STObject.formatted(outer));
    }
    return stArray;


  }


  STArray fromJSONArray( List<Map<String, dynamic>> jsonArray) {

        STArray arr = new STArray();

        for (int i = 0; i < jsonArray.length; i++) {
       //   Object o = jsonArray[i];
          arr.add(STObject.fromJSONObject(  jsonArray[i]));
        }

        return arr;
  }


  //STArray fromJSONObject(Map<String, dynamic> jsonObject) =>null;


//
//  STObject fromJSONObject(Map jsonObject) {
//    STObject so = new STObject();
//
//    jsonObject.forEach((k,v){
//
//      Field fieldKey = Field.fromString(k);
//      Object value   = v;
//      if (fieldKey != null) {
//        so.putTranslated(fieldKey, value);
//      }
//    });
//
//    return STObject.formatted(so);
//  }


//  Blob fromString(String value) {
//    return new Blob(Util.createUint8ListFromString(value));
//  }
//
//  void toBytesSink(Blob obj, BytesSink to) {
//    to.addBytes(obj.buffer);
//  }

//TODO
//  String toString(Blob obj) {
//    return B16.toString(obj.buffer);
//  }

//  Blob fromParser(BinaryParser parser, int hint) {
//    if (hint == null) {
//      hint = parser.size() - parser.pos();
//    }
//    return new Blob(parser.read(hint));
//  }

}
